amphitheatre library

A Flutter video player and editor.

Classes

Amphitheatre
The Amphitheatre video player.
AmphitheatreAnimatedPlayPauseButton
An animated play/pause button.
AmphitheatreCancelButton
A simple 'Cancel' button that inherits its icon and other semantics from AmphitheatreCloseButton. The default differences between the cancel and close buttons are that the cancel button will naturally have a 'Cancel' tooltip and the caption will always be shown.
AmphitheatreCloseButton
A simple 'Close' button with a tooltip. Pops the Navigator when tapped.
AmphitheatreController
Controls the Amphitheatre video player.
AmphitheatreDoneButton
A simple 'Done' button with a tooltip. Performs the onPressed action when pressed.
AmphitheatreEditor
The Amphitheatre video editor.
AmphitheatreEditorAction
The base class for actions that can be performed by the AmphitheatreEditor.
AmphitheatreEditorActionCrop
A crop action. This is when the duration of the video is shortened to a subset within the original video.
AmphitheatreEditorController
The controller for an AmphitheatreEditor. This is used in addition to the AmphitheatreController (which is for the video) to control the edit actions that should be applied to the video.
AmphitheatreEditorModifications
The set of modifications to be applied to a video.
AmphitheatreEditorOptions
Editing options for the AmphitheatreEditor.
AmphitheatreEditorSlider
The AmphitheatreEditorSlider replaces the existing editor slider with a CustomPainter-based slider that includes handles for cropping the video down to size.
AmphitheatreEditorStyle
Styling options for the AmphitheatreEditor.
AmphitheatreExporterProgress
The default exporter progress screen for the AmphitheatreEditor.
AmphitheatreLocalizations
Callers can lookup localized strings with an instance of AmphitheatreLocalizations returned by AmphitheatreLocalizations.of(context).
AmphitheatrePlatform
The platform interface for Amphitheatre and AmphitheatreEditor.
AmphitheatreProgressSlider
The progress slider for Amphitheatre. This renders a progress bar (by default with the application's primary color) and timestamps underneath.
AmphitheatreReplayButton
A simple 'Replay' icon with tooltip. Instructs the controller to replay the video when tapped.
AmphitheatreSkipButton
A skip button that skips either forward or back in time when tapped.
AmphitheatreVideo
Holds data about a video being displayed by Amphitheatre.
AmphitheatreVideoControls
The video controls for Amphitheatre.
AmphitheatreVideoInfo
Stores non-technical information about the video. See AmphitheatreController.info.
AmphitheatreVideoInfoDisplay
The video info for Amphitheatre.

Enums

AmphitheatreVisibility
Visibility types for Amphitheatre components.

Functions

lookupAmphitheatreLocalizations(Locale locale) AmphitheatreLocalizations
setAmphitheatrePlatform(AmphitheatrePlatform? platform) → void
Set the platform interface implementation for Amphitheatre and AmphitheatreEditor.

Typedefs

AmphitheatreCloseButtonAction = void Function(BuildContext context)
An action that is performed when the close button is pressed. Typically, this is just to pop the current navigation context (which is what _defaultOnCloseButtonPressed does).
AmphitheatreComponentBuilder = Widget Function(AmphitheatreController controller, bool showControls)
A builder for a Amphitheatre component. controller is for the video player that the component is being rendered for. showControls is true when the screen has been tapped and the controls should be shown and false otherwise.
AmphitheatreEditorRouteBuilder = Route<String?> Function(Widget child)
A builder for the Route that is used to open an AmphitheatreEditor when AmphitheatreEditor.launch is called.
AmphitheatreExporterProgressBuilder = Widget Function({required double progress})
A builder that returns a Scaffold, rendered when the AmphitheatreEditor is exporting the new video.
AmphitheatreRouteBuilder = Route<void> Function(Widget child)
A builder for the Route that is used to open Amphitheatre when Amphitheatre.launch is called.