Amphitheatre class

The Amphitheatre video player.

Inheritance

Constructors

Amphitheatre({required AmphitheatreController controller, AmphitheatreComponentBuilder buildCloseButton = _buildCloseButton, AmphitheatreComponentBuilder? buildDoneButton, AmphitheatreComponentBuilder buildReplayButton = _buildReplayButton, AmphitheatreComponentBuilder buildProgressSlider = _buildProgressSlider, AmphitheatreComponentBuilder buildVideoControls = _buildVideoControls, AmphitheatreComponentBuilder buildVideoInfo = _buildVideoInfo, bool enableToggleControls = true, bool enableReplayButton = true, bool autoPlay = true, Key? key})
The default constructor for Amphitheatre.
const
Amphitheatre.consume({required AmphitheatreController controller, AmphitheatreComponentBuilder buildCloseButton = _buildCloseButton, AmphitheatreComponentBuilder? buildDoneButton, AmphitheatreComponentBuilder buildReplayButton = _buildReplayButton, AmphitheatreComponentBuilder buildProgressSlider = _buildProgressSlider, AmphitheatreComponentBuilder buildVideoControls = _buildVideoControls, AmphitheatreComponentBuilder buildVideoInfo = _buildVideoInfo, bool enableToggleControls = true, bool enableReplayButton = true, bool autoPlay = true, Key? key})
Equivalent to the default constructor, Amphitheatre.new, but indicates to Amphitheatre that the controller has been 'consumed'.
const

Properties

autoPlay bool
If enabled, the video starts playing as soon as the controller has initialized and buffered it.
final
buildCloseButton AmphitheatreComponentBuilder
Builder for the close button. This button shows in the top-left of the screen when the controls are not hidden.
final
buildDoneButton AmphitheatreComponentBuilder?
Builder for the done button. This button shows in the top-right of the screen when the controls are not hidden.
final
buildProgressSlider AmphitheatreComponentBuilder
Builder for the progress slider. This button shows in the bottom third of the screen when the controls are not hidden.
final
buildReplayButton AmphitheatreComponentBuilder
Builder for the replay button. This button shows in the center of the screen when the video has ended.
final
buildVideoControls AmphitheatreComponentBuilder
Builder for the video controls (e.g., skip back, play/pause, skip forward). This button shows in the bottom third of the screen when the controls are not hidden.
final
buildVideoInfo AmphitheatreComponentBuilder
Builder for the video information. This shows underneath the video controls (buildVideoControls).
final
consumedController bool
If true, the Amphitheatre will automatically dispose of the controller when it is disposed.
final
controller AmphitheatreController
The controller for the Amphitheatre.
final
enableReplayButton bool
When true (as is the default) once the video has ended the controls will be hidden and only the replay and close buttons will be rendered instead.
final
enableToggleControls bool
When true (as is the default), tapping outside of the controls (i.e., on the video) will hide the controls and tapping again will show them. If this is false, that behavior is disabled.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Amphitheatre>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

launch(BuildContext context, {required AmphitheatreController controller, AmphitheatreRouteBuilder routeBuilder = _defaultAmphitheatreRouteBuilder, bool useRootNavigator = false, bool enableToggleControls = true, bool enableReplayButton = true, bool autoPlay = true}) → void
Launches the Amphitheatre with the given controller, consuming the controller. See Amphitheatre.consume.