autoPlay property

bool autoPlay
final

If enabled, the video starts playing as soon as the controller has initialized and buffered it.

This has no effect if the controller has already been initialized, hence the option is not available on the default constructor. Instead, see Amphitheatre.consume.

Implementation

final bool autoPlay;