buildCloseButton property
Builder for the close button. This button shows in the top-left of the screen when the controls are not hidden.
Implementation
final AmphitheatreComponentBuilder buildCloseButton;
Builder for the close button. This button shows in the top-left of the screen when the controls are not hidden.
final AmphitheatreComponentBuilder buildCloseButton;