buildDoneButton property
Builder for the done button. This button shows in the top-right of the screen when the controls are not hidden.
Implementation
final AmphitheatreComponentBuilder? buildDoneButton;
Builder for the done button. This button shows in the top-right of the screen when the controls are not hidden.
final AmphitheatreComponentBuilder? buildDoneButton;