buildProgressSlider property
Builder for the progress slider. This button shows in the bottom third of the screen when the controls are not hidden.
Implementation
final AmphitheatreComponentBuilder buildProgressSlider;
Builder for the progress slider. This button shows in the bottom third of the screen when the controls are not hidden.
final AmphitheatreComponentBuilder buildProgressSlider;