consumedController property
If true, the Amphitheatre will automatically dispose of the controller when it is disposed.
See Amphitheatre.consume and launch.
Implementation
final bool consumedController;
If true, the Amphitheatre will automatically dispose of the controller when it is disposed.
See Amphitheatre.consume and launch.
final bool consumedController;