AmphitheatreComponentBuilder typedef

AmphitheatreComponentBuilder = Widget Function(AmphitheatreController controller, bool showControls)

A builder for a Amphitheatre component. controller is for the video player that the component is being rendered for. showControls is true when the screen has been tapped and the controls should be shown and false otherwise.

The close and replay buttons are an exception; the close button is always built and the replay button is only built when the video has ended.

You do not need to manually handle showControls - the widget that the controls are being rendered in is hidden and ignored with AnimatedOpacity and IgnorePointer, respectively, when showControls is false. It can, however, be used to optimize your controls when they are not being shown.

Implementation

typedef AmphitheatreComponentBuilder = Widget Function(
  AmphitheatreController controller,
  bool showControls,
);