pause method
void
pause()
Instruct the controller to pause the video, whilst retaining the position.
Implementation
void pause() => unawaited(controller.pause());
Instruct the controller to pause the video, whilst retaining the position.
void pause() => unawaited(controller.pause());