AmphitheatreEditor class

The Amphitheatre video editor.

Inheritance

Constructors

AmphitheatreEditor({required AmphitheatreController controller, AmphitheatreEditorStyle style = const AmphitheatreEditorStyle(), AmphitheatreEditorOptions options = const AmphitheatreEditorOptions(), AmphitheatreComponentBuilder buildVideoControls = _buildVideoControls, AmphitheatreExporterProgressBuilder buildExporterProgress = _buildAmphitheatreExporterProgress, Key? key})
The default constructor for AmphitheatreEditor.
const
AmphitheatreEditor.consume({required AmphitheatreController controller, AmphitheatreEditorStyle style = const AmphitheatreEditorStyle(), AmphitheatreEditorOptions options = const AmphitheatreEditorOptions(), AmphitheatreComponentBuilder buildVideoControls = _buildVideoControls, AmphitheatreExporterProgressBuilder buildExporterProgress = _buildAmphitheatreExporterProgress, Key? key})
See Amphitheatre.consume.
const

Properties

buildExporterProgress AmphitheatreExporterProgressBuilder
The exporter progress screen builder.
final
buildVideoControls AmphitheatreComponentBuilder
Builder for the video controls (e.g., skip back, play/pause, skip forward). This button shows in the bottom third of the screen when the controls are not hidden.
final
consumedController bool
See Amphitheatre.consumedController.
final
controller AmphitheatreController
The controller for the Amphitheatre player.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
options AmphitheatreEditorOptions
Editing options for the AmphitheatreEditor.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style AmphitheatreEditorStyle
Styling options for the AmphitheatreEditor.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AmphitheatreEditor>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

launch(BuildContext context, {required AmphitheatreController controller, AmphitheatreEditorOptions options = const AmphitheatreEditorOptions(), AmphitheatreEditorRouteBuilder routeBuilder = _defaultAmphitheatreEditorRouteBuilder, bool useRootNavigator = false}) Future<String?>
Launches the AmphitheatreEditor with the given controller, consuming the controller. See AmphitheatreEditor.consume.