AmphitheatreEditorStyle class final

Styling options for the AmphitheatreEditor.

Annotations

Constructors

AmphitheatreEditorStyle({Color borderColor = Colors.white, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(12)), double borderThickness = 2.0, Color lineColor = Colors.red, double lineThickness = 2.0, Color cropColor = Colors.yellow, double cropHandleSize = 15.0, RawAssetImage? cropStartIcon = const RawAssetImage(size: Size.square(20), assetPath: 'assets/crop_start.svg', package: 'amphitheatre'), Color cropStartIconColor = Colors.black, RawAssetImage? cropEndIcon = const RawAssetImage(size: Size.square(20), assetPath: 'assets/crop_end.svg', package: 'amphitheatre'), Color cropEndIconColor = Colors.black})
Construct an AmphitheatreEditorStyle.
const

Properties

borderColor Color
The color to use when drawing the border around the playback slider.
final
borderRadius BorderRadius
The radius to draw the corners of the playback slider with.
final
borderThickness double
The thickness of the playback slider border.
final
cropColor Color
The color to use for the cropping handles.
final
cropEndIcon → RawAssetImage?
If specified, the RawAssetImage to paint on the crop end handle.
final
cropEndIconColor Color
The color to paint the cropEndIcon.
final
cropHandleSize double
The width to use for the cropping handles.
final
cropStartIcon → RawAssetImage?
If specified, the RawAssetImage to paint on the crop start handle.
final
cropStartIconColor Color
The color to paint the cropStartIcon.
final
hashCode int
The hash code for this object.
no setteroverride
lineColor Color
The color to use for the current progress line on the playback slider.
final
lineThickness double
The thickness to draw the current progress line with.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override