AmphitheatreRouteBuilder typedef

AmphitheatreRouteBuilder = Route<void> Function(Widget child)

A builder for the Route that is used to open Amphitheatre when Amphitheatre.launch is called.

This can be used to customize the route and therefore the transition that is used when an Amphitheatre is launched.

Implementation

typedef AmphitheatreRouteBuilder = Route<void> Function(Widget child);