enableReplayButton property
When true (as is the default) once the video has ended the controls will be hidden and only the replay and close buttons will be rendered instead.
Implementation
final bool enableReplayButton;
When true (as is the default) once the video has ended the controls will be hidden and only the replay and close buttons will be rendered instead.
final bool enableReplayButton;