AmphitheatreController class
Controls the Amphitheatre video player.
- Mixed-in types
Constructors
- AmphitheatreController({required VideoPlayerController controller, AmphitheatreVideoInfo? info, Duration animationDuration = const Duration(milliseconds: 200), Curve animationCurve = Curves.easeInOut})
- Construct the AmphitheatreController.
Properties
- animationCurve ↔ Curve
-
The curve to use for animations and transitions.
getter/setter pair
- animationDuration ↔ Duration
-
The duration to use for animations and transitions.
getter/setter pair
- aspectRatio → double
-
Returns the aspect ratio of the video.
no setter
- buffered → Duration?
-
Returns the greatest position that the player has buffered to, within the
video. The value is clamped to the maximum duration of the video.
no setter
- controller → VideoPlayerController
-
The controller for the underlying
VideoPlayer.final - duration → Duration
-
Returns the duration of the entire video.
no setter
- formattedDuration → String
-
Returns the formatted duration of the entire video.
no setter
- formattedPosition → String
-
Returns the formatted position of the player, within the video.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasVideoInfo → bool
-
Returns true if the info is not null and the
AmphitheatreVideoInfo.isNotEmpty.
no setter
- info → AmphitheatreVideoInfo?
-
Human-readable auxiliary information about the video. This can be used by
components that display the video information, but it has no impact on the
video itself (i.e., it is not technical metadata).
final
- isBuffering → bool
-
Returns whether the video is buffering.
no setter
- isCompleted → bool
-
Returns whether the video has been completed.
no setter
- isInitialized → bool
-
Returns true when the underlying controller has been initialized. This
is triggered by calling the initialize function on the
AmphitheatreController.
no setter
- isPlaying → bool
-
Returns whether the video is playing.
no setter
- position → Duration
-
Returns the position of the player, within the video.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Dispose the underlying controller, then the AmphitheatreController.
override
-
getVideo(
) → Future< AmphitheatreVideo> - Fetch the data for the video from the underlying controller (e.g., so it can be used by the AmphitheatreEditor).
-
initialize(
{bool autoPlay = true, bool looping = false}) → void - Initialize the underlying controller.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
pause(
) → void - Instruct the controller to pause the video, whilst retaining the position.
-
play(
) → void - Instruct the controller to start playing the video.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
replay(
) → void - Instruct the controller to start playing the video from the start.
-
seek(
Duration delta) → void -
Instruct the controller to seek by
delta, relative to the current position. -
seekTo(
Duration time) → void -
Instruct the controller to seek to the given
time. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited