AmphitheatreEditorOptions class final
Editing options for the AmphitheatreEditor.
- Annotations
Constructors
- AmphitheatreEditorOptions({Duration minLength = const Duration(seconds: 10), Duration maxLength = const Duration(minutes: 5), bool strict = false})
-
Construct the AmphitheatreEditorOptions.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxLength → Duration
-
The maximum length to allow the video to be.
final
- minLength → Duration
-
The minimum length to allow the video can be cropped to. If not set to
zero and the video is less than or equal to the minLength, the video
will be automatically accepted unless strict is true.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strict → bool
-
Whether to strictly require that videos conform to the specified
minLength and maxLength. If the video can never conform to the
constraints (i.e., it is too short), the video will be automatically
accepted when strict is true.
final
Methods
-
getDefaultOffsets(
Duration duration) → (Duration, Duration) - Returns the default start and end offsets for cropping. The offsets are based on computing the maximum length that can surround the middle of the video.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldAutoAccept(
Duration duration) → bool -
Whether strict and the constraints minLength and maxLength indicate
that the video with the given
durationshould be automatically accepted. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override