AmphitheatreEditorRouteBuilder typedef
A builder for the Route that is used to open an AmphitheatreEditor when AmphitheatreEditor.launch is called.
This can be used to customize the route and therefore the transition that is used when an AmphitheatreEditor is launched.
Implementation
typedef AmphitheatreEditorRouteBuilder = Route<String?> Function(Widget child);